@@ -70,6 +70,7 @@ class ApplicationConfig
     function ApplicationConfig ($configdir)
     {
         $this->configdir = $configdir;
+        $this->parameters = []; 
     }
 
 
@@ -84,13 +85,11 @@ class ApplicationConfig
      */
     function load ($file,$die_on_error=true)
     {
-        $this->parameters = '';
         $cfile = $this->configdir .'/'. $file;
 
         if (! $fd = @fopen ($cfile, "r")) {
             $dir = $_SERVER['SCRIPT_FILENAME'];
-            $script_path = dirname($dir);
-	        error_log('WARNING: Cannot open config file: '.$script_path. '/'.$cfile);
+	        error_log('WARNING: Cannot open config file: '.$cfile);
             if ($die_on_error) {
                 die ("ERROR: Cannot open config file.\n");
             }
@@ -141,6 +140,29 @@ class ApplicationConfig
         }
     }
 
+
+    /**
+     * Get array of config values
+     *
+     * @access public
+     * @param string $name
+     * @param string $default (optional)
+     * @return arrray $params
+     */
+    function getConfigList ($name,$default=false)
+    {
+        if (isset($this->parameters[$name])) {
+            return  preg_split('/,(\s+)?/',$this->parameters[$name]);
+        }
+        else if ($default) {
+            return $default;
+        }
+        else {
+            return false;
+        }
+    }
+
+
     /**
      * Fetch message
      *
