@@ -38,7 +38,7 @@ $sessionMailId = $App->getParam('sessionMailId');
 $mailTo = $App->getParam('mailTo');
 
 try {
-    $rawMail = $Backend->fetchRaw($sessionMailId);
+    $rawMail = $Backend->fetchRaw($archive,$sessionMailId);
     // Linebreak in $rawMail must be \r\n. Otherwise the whole mail content
     // (whith headers) will be send as mail body.
     $rawMail = preg_replace('/^Message-Id:/im','X-Benno-Resent-Message-Id:',$rawMail);
@@ -57,7 +57,7 @@ try {
     fclose($ph);
 
     $bennoId = QueryResult::getBennoId($sessionMailId);
-    $Audit->log("MAIL $Backend->archive:".$bennoId.' >> '.$mailTo);
+    $Audit->log("MAIL $archive:".$bennoId.' >> '.$mailTo);
 }
 catch (Exception $e) {
     $App->log('[a_forward] '.$e->getMessage());
